@@ -147,19 +147,16 @@ main (int argc, char **argv)
 	CommandLineData *data = NULL;
 	gint i;
 
-#ifdef ENABLE_NLS
-	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GEDIT_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-#endif
 
 	/* Initialize gnome program */
-	program = gnome_program_init ("gedit2", VERSION,
+	program = gnome_program_init ("gedit", VERSION,
 			    LIBGNOMEUI_MODULE, argc, argv,
 			    GNOME_PARAM_POPT_TABLE, options,
 			    GNOME_PARAM_HUMAN_READABLE_NAME,
-		            _("The gnome text editor"),
+		            _("The GNOME text editor"),
 			    NULL);
 
 	/* Set default icon */
@@ -185,7 +182,7 @@ main (int argc, char **argv)
 	if (args)	
 		for (i = 0; args[i]; i++) 
 		{
-			if (strstr (args[i], "+")) 
+			if (*args[i] == '+') 
 				data->line_pos = atoi (args[i] + 1);		
 			else
 				data->file_list = g_list_append (data->file_list, args[i]);
@@ -256,3 +253,26 @@ gedit_get_ui_component_from_window (BonoboWindow* win)
 
 	return bonobo_mdi_get_ui_component_from_window (win);
 }
+
+/* Return a newly allocated list */
+GList*
+gedit_get_open_documents (void)
+{
+	GList* children;
+	GList* docs = NULL;
+	g_return_val_if_fail (gedit_mdi != NULL, NULL);
+
+	children = bonobo_mdi_get_children (BONOBO_MDI (gedit_mdi));
+
+	while (children != NULL)
+	{
+		GeditMDIChild *child;
+
+		child = GEDIT_MDI_CHILD (children->data);
+		
+		docs = g_list_append (docs, child->document);
+		children = g_list_next (children);
+	}
+	
+	return docs;
+}
